@@ -24,11 +24,11 @@ class Migration(migrations.Migration):
         migrations.AddField(
             model_name='maylikeplugin',
             name='catagory',
-            field=models.ForeignKey(related_name='+', default=None, blank=True, to='aldryn_categories.Category', null=True),
+            field=models.ForeignKey(related_name='+', default=None, blank=True, to='aldryn_categories.Category', null=True, on_delete=models.CASCADE),
         ),
         migrations.AddField(
             model_name='maylikeplugin',
             name='tag',
-            field=models.ForeignKey(related_name='+', default=None, blank=True, to='taggit.Tag', null=True),
+            field=models.ForeignKey(related_name='+', default=None, blank=True, to='taggit.Tag', null=True, on_delete=models.CASCADE),
         ),
     ]
