@@ -3,6 +3,8 @@
 conda create -p $HOME/app/templates_shop/ZephyrusEnv/Env$1 python=3.7 -y
 conda activate $HOME/app/templates_shop/ZephyrusEnv/Env$1
 
+pip install -U Iuppiter
+pip install -U Zephyrus
 pip install -r $HOME/app/templates_shop/ZephyrusEnv/REQUIREMENTS_$1.txt
 pip install -U django-cms==$1
 pip install -U django==2.2.10
