@@ -1,6 +1,6 @@
 #!/usr/bin/env python
 # -*- coding: utf-8 -*-
-# $Id: build_boilerplate2.py 11671 2019-08-07 04:50:27Z Lavender $
+# $Id: build_boilerplate2.py 12436 2020-07-30 08:41:42Z Lavender $
 #
 # Copyright (c) 2017 Nuwa Information Co., Ltd, All Rights Reserved.
 #
@@ -12,8 +12,8 @@
 # limitations under the License.
 #
 # $Author: Lavender $
-# $Date: 2019-08-07 12:50:27 +0800 (Wed, 07 Aug 2019) $
-# $Revision: 11671 $
+# $Date: 2020-07-30 16:41:42 +0800 (Thu, 30 Jul 2020) $
+# $Revision: 12436 $
 
 import os
 import re
@@ -89,11 +89,11 @@ LEGEL = "\n%s\n" % get_template('boilerplate/txt/Legel.txt').render()
 
 # cms --------------------------------------------------------------------------
 CMS_HEAD_FRONT_TAG = ("{% load cms_tags menu_tags sekizai_tags staticfiles %}"
-                      "{% with '' as CMS_STATIC_DIR %}")
-CMS_HEAD_BACK_TAG = "{% endwith %}{% render_block 'css' %}"
+                      "{% with '' as CMS_STATIC_PREFIX %}{% with '/' as CMS_LINK_PREFIX %}")
+CMS_HEAD_BACK_TAG = "{% endwith %}{% endwith %}{% render_block 'css' %}"
 
-CMS_BODY_FRONT_TAG = "{% cms_toolbar %}{% with '' as CMS_STATIC_DIR %}"
-CMS_BODY_BACK_TAG = "{% endwith %}{% render_block 'js' %}"
+CMS_BODY_FRONT_TAG = "{% cms_toolbar %}{% with '' as CMS_STATIC_PREFIX %}{% with '/' as CMS_LINK_PREFIX %}"
+CMS_BODY_BACK_TAG = "{% endwith %}{% endwith %}{% render_block 'js' %}"
 
 CMS_PAGE_ATTRS_COMMENT = '''
     CMS page attribute
@@ -681,11 +681,12 @@ class Command(BaseCommand):
                         content = content.replace(fileDict[path], '/')
                     index = path.index(".html")
                     href = path[0:index]
-                    templatePath = "/" + href
+                    templatePath = \
+                        "{{ CMS_LINK_PREFIX|add:'" + href + "' }}"
                     content = content.replace(fileDict[path], templatePath)
                 else:
                     staticPath = \
-                        "{% static CMS_STATIC_DIR|add:'" + path + "' %}"
+                        "{% static CMS_STATIC_PREFIX|add:'" + path + "' %}"
                     content = content.replace(fileDict[path], staticPath)
 
         with open(filePath, 'w') as f:
