@@ -1,6 +1,6 @@
 #!/usr/bin/env python
 # -*- coding: utf-8 -*-
-# $Id: pluginize.py 12449 2020-08-06 06:53:34Z Lavender $
+# $Id: pluginize.py 12544 2020-10-08 06:33:19Z Lavender $
 #
 # Copyright (c) 2015 Nuwa Information Co., Ltd, All Rights Reserved.
 #
@@ -12,8 +12,8 @@
 # limitations under the License.
 #
 # $Author: Lavender $
-# $Date: 2020-08-06 14:53:34 +0800 (Thu, 06 Aug 2020) $
-# $Revision: 12449 $
+# $Date: 2020-10-08 14:33:19 +0800 (Thu, 08 Oct 2020) $
+# $Revision: 12544 $
 
 import os
 import json
@@ -156,12 +156,6 @@ class Placeholder2(Placeholder):
             if not hasPlugin:
                 string = content.lower().strip()
                 
-                string = '''
-                <img scr='data:   '>
-                <img scr='data:'>
-                <img scr='data:'>
-                '''
-                
                 isOutSideTag = False
                 if string.startswith('<') and string.endswith('>'):
                     isOutSideTag = True
